@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11639 2019-06-19 05:13:41Z Lavender $
+# $Id: __init__.py 11715 2019-09-18 14:34:08Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-06-19 13:13:41 +0800 (週三, 19 六月 2019) $
-# $Revision: 11639 $
+# $Date: 2019-09-18 23:34:08 +0900 (週三, 18 九月 2019) $
+# $Revision: 11715 $
 
 import os
 import sys
@@ -41,9 +41,6 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
                                  extendDatabaseDefaults, 
                                  extendAuthenticationBackend)
 
-from oscar import get_core_apps
-from oscar import OSCAR_MAIN_TEMPLATE_DIR
-
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ugettext as _2
 from django.core.urlresolvers import reverse
@@ -130,20 +127,62 @@ def attachSettings(settingsDict, enablePaypal=False):
     @param settingsDict locals() in settings.py.
     @param enablePaypal enable pay with paypal or not
     """
-
+    from oscar import VERSION
+    
     #=========================================================================
     # Django plugins.
-
     extraApps = []
     
     if 'IUNO_SHOP_EXTRA_APPS' in settingsDict:
         extraApps = settingsDict['IUNO_SHOP_EXTRA_APPS']
 
-    ADDING_INSTALLED_APPS = (
-        'django.contrib.sites',
-        'django.contrib.flatpages',
-        'widget_tweaks',
-    ) + tuple(get_core_apps(extraApps))
+    if VERSION >= (2, 0): # 大於版本 2.0
+        from oscar import INSTALLED_APPS
+        
+        def get_core_apps(overrides=None):
+            """
+            Return a list of oscar's apps amended with any passed overrides
+            """
+            if not overrides:
+                return INSTALLED_APPS
+
+            # Conservative import to ensure that this file can be loaded
+            # without the presence Django.
+            from django.utils import six
+            if isinstance(overrides, six.string_types):
+                raise ValueError(
+                    "get_core_apps expects a list or tuple of apps "
+                    "to override")
+
+            def get_app_label(app_label, overrides):
+                pattern = app_label.replace('oscar.apps.', '')
+                for override in overrides:
+                    if override.endswith(pattern):
+                        if 'dashboard' in override and 'dashboard' not in pattern:
+                            continue
+                        return override
+                return app_label
+
+            apps = []
+            for app_label in INSTALLED_APPS:
+                apps.append(get_app_label(app_label, overrides))
+            return apps
+            
+        ADDING_INSTALLED_APPS = (
+            'django.contrib.sites',
+            'django.contrib.flatpages',
+            'widget_tweaks',
+            'sorl.thumbnail',
+        ) + tuple(get_core_apps(extraApps))
+    else:
+        from oscar import get_core_apps
+        
+        ADDING_INSTALLED_APPS = (
+            'django.contrib.sites',
+            'django.contrib.flatpages',
+            'widget_tweaks',
+        ) + tuple(get_core_apps(extraApps))
+    
     
     ADDING_INSTALLED_APPS += (
         'Iuno.shop',
@@ -192,12 +231,16 @@ def attachSettings(settingsDict, enablePaypal=False):
     #  Context processors
     ADDING_TEMPLATES_CONTEXT_PROCESSORS = (
         'oscar.apps.search.context_processors.search_form',
-        'oscar.apps.promotions.context_processors.promotions',
         'oscar.apps.checkout.context_processors.checkout',
         'oscar.apps.customer.notifications.context_processors.notifications',
         'oscar.core.context_processors.metadata',                       
     )
     
+    if not VERSION >= (2, 0):
+        ADDING_TEMPLATES_CONTEXT_PROCESSORS += (
+            'oscar.apps.promotions.context_processors.promotions',
+        )
+    
     extendTemplateContextProcessors(settingsDict, 
                                     ADDING_TEMPLATES_CONTEXT_PROCESSORS)
 
@@ -206,6 +249,14 @@ def attachSettings(settingsDict, enablePaypal=False):
         os.path.join("templates", "shop", "override"))
         
     # Template tags
+    if VERSION >= (2, 0):
+        from oscar import config
+        OSCAR_MAIN_TEMPLATE_DIR = os.path.join(
+            os.path.dirname(
+                os.path.abspath(config.__file__)), 'templates/oscar')
+    else:
+        from oscar import OSCAR_MAIN_TEMPLATE_DIR
+        
     ADDING_TEMPLATES_DIRS = [
         os.path.join(settingsDict['BASE_DIR'], 'templates'),
         overrideTemplateDir,
@@ -453,7 +504,16 @@ def attachSettings(settingsDict, enablePaypal=False):
             raise KeyError("You should also set '%s' value." % str(unsettings))
     
     #=========================================================================
-
+    
+    #=========================================================================
+    # oscar ckeditor dashboard
+    DEFAULT_CKEDITOR_SETTINGS = {
+        'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR': True,
+        'IUNO_SHOP_CONTENT_BLOCK_CKEDITOR': True,
+        'IUNO_SHOP_PAGE_CKEDITOR': True,
+    }
+    update(settingsDict, DEFAULT_CKEDITOR_SETTINGS)
+    
     
 
 def attachShopURLs(settings, urlpatterns):
@@ -468,16 +528,25 @@ def attachShopURLs(settings, urlpatterns):
 
     from django.conf.urls import url, include
     from django.contrib.admin.views.decorators import staff_member_required
-    from oscar.app import application as shop
-    from paypal.express.dashboard.app import application
+    from oscar import VERSION       
     
     urlpatterns += patterns('',
         # the i18n is the default url settings of django oscar, but generally
         # we are not used.
         url(r'^i18n/', include('django.conf.urls.i18n')),
-        url(r'^shop/', shop.urls),
         url(r'^checkout/payment/redirect/', views.sendPaymentForm, name="formRedirect"),
     )
+    if VERSION >= (2, 0, 0):
+        from django.apps import apps
+        urlpatterns += patterns('',
+            url(r'^shop/', include(apps.get_app_config('oscar').urls[0])),
+        )
+    else:
+        from oscar.app import application as shop
+        from paypal.express.dashboard.app import application
+        urlpatterns += patterns('',
+            url(r'^shop/', shop.urls),
+        )
     
     ckeditorEnable = False
     if hasattr(settings, 'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR'):
@@ -508,13 +577,14 @@ def attachShopURLs(settings, urlpatterns):
     if hasattr(settings, 'IUNO_SHOP_CATHAYBK_ENABLE'):
         cathaybkEnable = settings.IUNO_SHOP_CATHAYBK_ENABLE
 
-    if paypalEnable:
-        urlpatterns += patterns('',          
-            url(r'^shop/dashboard/paypal/express/', application.urls),
-            url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
-                views.SuccessResponseView.as_view(), name='paypal-place-order'),
-            url(r'^checkout/paypal/', include('paypal.express.urls')),
-        )
+    if not VERSION >= (2, 0, 0):
+        if paypalEnable:
+            urlpatterns += patterns('',          
+                url(r'^shop/dashboard/paypal/express/', application.urls),
+                url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
+                    views.SuccessResponseView.as_view(), name='paypal-place-order'),
+                url(r'^checkout/paypal/', include('paypal.express.urls')),
+            )
 
     if cathaybkEnable:
         urlpatterns += patterns('',
