@@ -3,6 +3,54 @@
 
 
 from django.db import models
+from django.utils.translation import gettext_lazy as _
+
+TEXT = "text"
+INTEGER = "integer"
+BOOLEAN = "boolean"
+FLOAT = "float"
+RICHTEXT = "richtext"
+DATE = "date"
+DATETIME = "datetime"
+OPTION = "option"
+MULTI_OPTION = "multi_option"
+ENTITY = "entity"
+FILE = "file"
+IMAGE = "image"
+TYPE_CHOICES = (
+    (TEXT, _("Text")),
+    (INTEGER, _("Integer")),
+    (BOOLEAN, _("True / False")),
+    (FLOAT, _("Float")),
+    (RICHTEXT, _("Rich Text")),
+    (DATE, _("Date")),
+    (DATETIME, _("Datetime")),
+    (OPTION, _("Option")),
+    #(MULTI_OPTION, _("Multi Option")),
+    #(ENTITY, _("Entity")),
+    (FILE, _("File")),
+    (IMAGE, _("Image")),
+)
+
+class OptionType(models.Model):
+    option = models.ForeignKey(
+        'catalogue.Option',
+        on_delete=models.CASCADE,
+        verbose_name=_("Option")
+    )
+    
+    type = models.CharField(
+        choices=TYPE_CHOICES, default=TYPE_CHOICES[0][0],
+        max_length=20, verbose_name=_("Type"))
+    optionGroup = models.ForeignKey(
+        'catalogue.AttributeOptionGroup',
+        blank=True,
+        null=True,
+        on_delete=models.CASCADE,
+        related_name='productAttributes',
+        verbose_name=_("Option Group"),
+        help_text=_(
+            'Select an option group if using type "Option" or "Multi Option"'))
 
 class ECPayTrade(models.Model):
     merchantId = models.CharField(max_length=30)
