@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11635 2019-06-12 07:29:45Z Lavender $
+# $Id: views.py 11639 2019-06-19 05:13:41Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-12 16:29:45 +0900 (週三, 12 六月 2019) $
-# $Revision: 11635 $ 
+# $Date: 2019-06-19 14:13:41 +0900 (週三, 19 六月 2019) $
+# $Revision: 11639 $ 
 
 import json
 import logging
@@ -420,16 +420,19 @@ def returnCathaybkCreditXml(request):
         
 def sendPaymentForm(request):
     if request.method == 'POST':
+        encryptor = Encryptor(settings.SECRET_KEY.encode())
         formData = request.POST.get("formData")
+        if not formData:
+            raise Http404()
         request.session['preBasketId'] = request.basket.id
         request.basket.freeze()
         return render(
                 request, 
                 "shop/payment/PaymentRedirect.html", 
-                {'form': base64.b64decode(formData),}
+                {'form': encryptor.decrypt(base64.b64decode(formData)),}
             )
     else:
-        return Http404
+        raise Http404()
     
 
 class SuccessResponseView2(_PaymentDetailsView):
